FontFrame

Struct FontFrame 

pub struct FontFrame { /* private fields */ }
A font that can be rendered as a PixelFrame with a stroke color, and a background color.

Implementations

Source

impl FontFrame

pub fn new( font: FontUnicode, stroke: PixelColor, background: PixelColor, ) -> Self

Create a new font frame with a stroke color, and a background color.

pub fn pixel_frame(&self) -> PixelFrame

The PixelFrame for this font.