[−][src]Struct sensehat_screen::fonts::FontString
A FontString is a collection of FontUnicode which can be rendered to frames for the LED
Matrix.
Implementations
impl FontString[src]
pub fn new() -> Self[src]
Create an empty FontString.
pub fn chars(&self) -> Vec<char>[src]
Render the font string as a collection of unicode value points, Vec<char>.
pub fn font_frames(&self, stroke: PixelColor, bg: PixelColor) -> Vec<FontFrame>[src]
Returns a Vec<FontFrame> for each inner font.
pub fn pixel_frames(
&self,
stroke: PixelColor,
bg: PixelColor
) -> Vec<PixelFrame>[src]
&self,
stroke: PixelColor,
bg: PixelColor
) -> Vec<PixelFrame>
Returns a Vec<PixelFrame> for each inner font.