[−][src]Struct sensehat_screen::frame::PixelFrame
A frame of pixels. This is the basic representation for the LED Matrix display.
Methods
impl PixelFrame[src]
Methods enabled by the clip feature.
pub fn clip(&self, other: &PixelFrame, clip_at: Offset) -> Self[src]
Shortcut to get a PixelFrame from a temporary Clip, at a given Offset.
For memory reallocation, such as when rendering a clip at multiple offsets,
it is better to use PixelFrame::build_clip.
pub fn build_clip(&self, other: &PixelFrame) -> Clip[src]
Create a Clip with this and another PixelFrame.
impl PixelFrame[src]
Methods enabled by the offset feature.
impl PixelFrame[src]
Methods enabled by the rotate feature.
pub fn rotate(&self, rotate: Rotate) -> Self[src]
Create a new PixelFrame that is rotated by a multiple of 90°, counter-clockwise.
impl PixelFrame[src]
pub const BLACK: PixelFrame[src]
pub const RED: PixelFrame[src]
pub const BLUE: PixelFrame[src]
pub const GREEN: PixelFrame[src]
pub const WHITE: PixelFrame[src]
pub const YELLOW: PixelFrame[src]
pub const CYAN: PixelFrame[src]
pub const MAGENTA: PixelFrame[src]
impl PixelFrame[src]
pub fn new(pixels: &[PixelColor; 64]) -> Self[src]
Create a FrameLine representing the current PixelFrame.
pub fn frame_line(&self) -> FrameLine[src]
Create a FrameLine representing the current PixelFrame.
pub fn transpose(&mut self)[src]
Transpose the LED Matrix. Rows become columns.
pub fn flip_h(&mut self)[src]
Flip the LED Matrix horizontally.
pub fn flip_v(&mut self)[src]
Flip the LED Matrix vertically.
pub fn reverse(&mut self)[src]
Reverse the LED Matrix.
pub fn as_rows(&self) -> [[PixelColor; 8]; 8][src]
Returns a [[PixelColor; 8]; 8], organized by rows, from top to bottom.
pub fn as_columns(&self) -> [[PixelColor; 8]; 8][src]
Returns a [[PixelColor; 8]; 8], organized by columns, from left to right.
pub fn from_rows(rows: &[[PixelColor; 8]; 8]) -> Self[src]
Create a new PixelFrame from a [[PixelColor; 8]; 8], of 8 rows with 8 PixelColors.
pub fn from_columns(columns: &[[PixelColor; 8]; 8]) -> Self[src]
Create a new PixelFrame from a [[PixelColor; 8]; 8], of 8 columns with 8 PixelColors.