[−][src]Struct sensehat_screen::screen::Screen
This is the main type for interacting with the LED Matrix Screen.
Implementations
impl Screen[src]
pub fn open(path: &str) -> Result<Self, ScreenError>[src]
Open the framebuffer to the screen at the given file-system path.
pub fn write_frame(&mut self, frame: &FrameLine)[src]
Write the contents of a FrameLine into the framebuffer. This will
render the frameline on the screen.