[][src]Struct sensehat_screen::scroll::FrameSequence

pub struct FrameSequence { /* fields omitted */ }

A sequence of frames to be scrolled on the LED Matrix.

Implementations

impl FrameSequence[src]

pub fn positions(&self) -> usize[src]

Returns the number of positions that the frame sequence can render as pixel frames.