[−][src]Struct sensehat_screen::scroll::Scroll
A type representing a collection of PixelFrames that may be scrolled.
Implementations
impl Scroll[src]
pub fn new(frames: &[PixelFrame]) -> Self[src]
Creates a new scroll from a slice of PixelFrames.
Panics
The scroll needs at least 2 PixelFrames to be created.
pub fn frames(&self) -> &[PixelFrame][src]
Returns &[PixelFrame] with the pixel frames that constitute this scroll.
pub fn clips(&self) -> Vec<Clip>[src]
Returns Vec<Clip> with the pixel frames clips that may be rendered.
pub fn reverse(&mut self)[src]
Reverse the order of the inner pixel frames.
pub fn len(&self) -> usize[src]
Return the number of pixel frames in the scroll.
pub fn is_empty(&self) -> bool[src]
Returns true if the scroll has no pixel frames.
pub fn right_to_left(&self) -> FrameSequence[src]
Returns a FrameSequence iterator that moves the frames from the right to the left.
pub fn left_to_right(&self) -> FrameSequence[src]
Returns a FrameSequence iterator that moves the frames from the left to the right.
pub fn top_to_bottom(&self) -> FrameSequence[src]
Returns a FrameSequence iterator that moves the frames from the top to the bottom.
pub fn bottom_to_top(&self) -> FrameSequence[src]
Returns a FrameSequence iterator that moves the frames from the bottom to the bottom.