pub struct FontFrame { /* private fields */ }Expand description
A font that can be rendered as a PixelFrame with a stroke color, and a background color.
Implementations
Sourceimpl FontFrame
impl FontFrame
Sourcepub fn new(
font: FontUnicode,
stroke: PixelColor,
background: PixelColor,
) -> Self
pub fn new( font: FontUnicode, stroke: PixelColor, background: PixelColor, ) -> Self
Create a new font frame with a stroke color, and a background color.
Sourcepub fn pixel_frame(&self) -> PixelFrame
pub fn pixel_frame(&self) -> PixelFrame
The PixelFrame for this font.