[][src]Struct sensehat_screen::fonts::FontFrame

pub struct FontFrame { /* fields omitted */ }

A font that can be rendered as a PixelFrame with a stroke color, and a background color.

Methods

impl FontFrame[src]

pub fn new(
    font: FontUnicode,
    stroke: PixelColor,
    background: PixelColor
) -> Self
[src]

Create a new font frame with a stroke color, and a background color.

pub fn pixel_frame(&self) -> PixelFrame[src]

The PixelFrame for this font.