[−][src]Struct sensehat_screen::fonts::FontFrame
A font that can be rendered as a PixelFrame with a stroke color, and a background color.
Methods
impl FontFrame[src]
pub fn new(
font: FontUnicode,
stroke: PixelColor,
background: PixelColor
) -> Self[src]
font: FontUnicode,
stroke: PixelColor,
background: PixelColor
) -> Self
Create a new font frame with a stroke color, and a background color.
pub fn pixel_frame(&self) -> PixelFrame[src]
The PixelFrame for this font.