Struct sensehat_screen::fonts::FontFrame[][src]

pub struct FontFrame { /* fields omitted */ }

A font that can be rendered as a PixelFrame with a stroke color, and a background color.

Methods

impl FontFrame
[src]

Create a new font frame with a stroke color, and a background color.

The PixelFrame for this font.