Struct sensehat_screen::fonts::FontFrame [−][src]
pub struct FontFrame { /* fields omitted */ }A font that can be rendered as a PixelFrame with a stroke color, and a background color.
Methods
impl FontFrame[src]
impl FontFramepub fn new(
font: FontUnicode,
stroke: PixelColor,
background: PixelColor
) -> Self[src]
pub fn new(
font: FontUnicode,
stroke: PixelColor,
background: PixelColor
) -> SelfCreate a new font frame with a stroke color, and a background color.
pub fn pixel_frame(&self) -> PixelFrame[src]
pub fn pixel_frame(&self) -> PixelFrameThe PixelFrame for this font.