Struct sensehat_screen::fonts::FontString [−][src]
pub struct FontString(_);
A FontString is a collection of FontUnicode which can be rendered to frames for the LED
Matrix.
Methods
impl FontString[src]
impl FontStringpub fn new() -> Self[src]
pub fn new() -> SelfCreate an empty FontString.
pub fn chars(&self) -> Vec<char>[src]
pub fn chars(&self) -> Vec<char>Render the font string as a collection of unicode value points, Vec<char>.
pub fn to_string(&self) -> String[src]
pub fn to_string(&self) -> StringRender the font string as a String.
pub fn font_frames(&self, stroke: PixelColor, bg: PixelColor) -> Vec<FontFrame>[src]
pub fn font_frames(&self, stroke: PixelColor, bg: PixelColor) -> Vec<FontFrame>Returns a Vec<FontFrame> for each inner font.
pub fn pixel_frames(
&self,
stroke: PixelColor,
bg: PixelColor
) -> Vec<PixelFrame>[src]
pub fn pixel_frames(
&self,
stroke: PixelColor,
bg: PixelColor
) -> Vec<PixelFrame>Returns a Vec<PixelFrame> for each inner font.