Struct sensehat_screen::screen::Screen [−][src]
pub struct Screen { /* fields omitted */ }This is the main type for interacting with the LED Matrix Screen.
Methods
impl Screen[src]
impl Screenpub fn open(path: &str) -> Result<Self, ScreenError>[src]
pub fn open(path: &str) -> Result<Self, ScreenError>Open the framebuffer to the screen at the given file-system path.
pub fn write_frame(&mut self, frame: &FrameLine)[src]
pub fn write_frame(&mut self, frame: &FrameLine)Write the contents of a FrameLine into the framebuffer. This will
render the frameline on the screen.